@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.111-3-gb7e4ea1
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.112-8-g794452f
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.112';
+our $VERSION = '0.113';
 
 use Moose;
 with
@@ -15,13 +15,13 @@ with
 
 use Dist::Zilla::Util;
 use Moose::Util::TypeConstraints qw(enum subtype where);
-use List::Util 1.33 qw(first any);
+use List::Util 1.45 qw(first any uniq);
 use Module::Runtime 'require_module';
 use Devel::CheckBin 'can_run';
 use Path::Tiny;
 use CPAN::Meta::Requirements;
 use Term::ANSIColor 'colored';
-use namespace::autoclean -also => ['_uniq'];
+use namespace::autoclean;
 
 sub mvp_multivalue_args { qw(installer copy_file_from_release) }
 
@@ -65,7 +65,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    sort(_uniq($self->$orig(@_), qw(LICENCE LICENSE CONTRIBUTING Changes ppport.h INSTALL)));
+    sort(uniq($self->$orig(@_), qw(LICENCE LICENSE CONTRIBUTING Changes ppport.h INSTALL)));
 };
 
 has changes_version_columns => (
@@ -113,7 +113,12 @@ my @network_plugins = qw(
 my %network_plugins;
 @network_plugins{ map { Dist::Zilla::Util->expand_config_package_name($_) } @network_plugins } = () x @network_plugins;
 
-my $has_bash = can_run('bash');
+has _has_bash => (
+    is => 'ro',
+    isa => 'Bool',
+    lazy => 1,
+    default => sub { !!can_run('bash') },
+);
 
 # files that might be in the repository that should never be gathered
 my @never_gather = qw(
@@ -139,7 +144,7 @@ sub configure
     my $self = shift;
 
     warn '[@Author::ETHER] no "bash" executable found; skipping Run::AfterBuild commands to update .ackrc and .latest symlink', "\n"
-        if not $has_bash;
+        if not $self->_has_bash;
 
     # NOTE! since the working directory has not changed to $zilla->root yet,
     # if running this code via a different mechanism than dzil <command>, file
@@ -290,7 +295,7 @@ sub configure
         [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
 
         # note that MBT::*'s static tweak is consequently adjusted, later
-        [ 'StaticInstall' => { ':version' => '0.005', mode => $static_install_mode, dry_run => $static_install_dry_run } ],
+        [ 'StaticInstall'       => { ':version' => '0.005', mode => $static_install_mode, dry_run => $static_install_dry_run } ],
 
         # Test Runners (load after installers to avoid a rebuild)
         [ 'RunExtraTests'       => { ':version' => '0.024' } ],
@@ -298,7 +303,7 @@ sub configure
         # After Build
         'CheckSelfDependency',
 
-        ( $has_bash ?
+        ( $self->_has_bash ?
             [ 'Run::AfterBuild' => '.ackrc' => { ':version' => '0.038', quiet => 1, run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
             : ()),
         [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.038', quiet => 1, eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
@@ -332,7 +337,7 @@ sub configure
         [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
         [ 'ReadmeAnyFromPod'    => { ':version' => '0.142180', type => 'pod', location => 'root', phase => 'release' } ],
 
-        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } sort(_uniq('README.md', 'README.pod', $self->copy_files_from_release)) ], commit_msg => '%N-%v%t%n%n%c' } ],
+        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } sort(uniq('README.md', 'README.pod', $self->copy_files_from_release)) ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
 
@@ -346,7 +351,7 @@ sub configure
     # hopefully the file is available at this location soonish after release!
     my ($username, $password) = $self->_pause_config;
     push @plugins,
-        [ 'Run::AfterRelease' => 'install release' => { ':version' => '0.031', fatal_errors => 0, run => 'cpanm http://' . $username . ':' . $password . '@pause.perl.org/pub/PAUSE/authors/id/' . substr($username, 0, 1).'/'.substr($username,0,2).'/'.$username.'/%a' } ] if $username and $password;
+        [ 'Run::AfterRelease'   => 'install release' => { ':version' => '0.031', fatal_errors => 0, run => 'cpanm http://' . $username . ':' . $password . '@pause.perl.org/pub/PAUSE/authors/id/' . substr($username, 0, 1).'/'.substr($username,0,2).'/'.$username.'/%a' } ] if $username and $password;
 
     if ($self->airplane)
     {
@@ -438,8 +443,6 @@ sub _pause_config
     } $file->lines;
 }
 
-sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
-
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -454,7 +457,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.112
+version 0.113
 
 =head1 SYNOPSIS
 
@@ -973,9 +976,9 @@ allocated in Changes entries to the version string. Defaults to 10.
 Available since 0.101.
 
 A string that specifies the name to use for the licence file.  Defaults to
-C<LICENCE> for distributions where I (ETHER) have first-come, or C<LICENSE>
-otherwise. (The pod section for legal information is also adjusted
-appropriately.)
+C<LICENCE> for distributions where I (ETHER) or any other known non-Americans
+have first-come permissions, or C<LICENSE> otherwise.
+(The pod section for legal information is also adjusted appropriately.)
 
 =for stopwords customizations
 
