@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 
-our $VERSION = '0.112';
+our $VERSION = '0.113';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -29,7 +29,10 @@ sub configure
     my $licence_filename = $licence_plugin ? $licence_plugin->filename : 'LICENCE';
 
     return (
-        '@CorePrep',
+        # equivalent to [@CorePrep]
+        [ '-EnsurePod5' ],
+        [ '-H1Nester' ],
+
         '-SingleEncoding',
         [ '-Transformer' => List => { transformer => 'List' } ],
         [ '-Transformer' => Verbatim => { transformer => 'Verbatim' } ],
@@ -177,7 +180,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.112
+version 0.113
 
 =head1 SYNOPSIS
 
@@ -202,7 +205,8 @@ It is also used automatically when your F<dist.ini> contains:
 This is a L<Pod::Weaver> plugin bundle. It is I<approximately> equal to the
 following F<weaver.ini>, minus some optimizations:
 
-    [@CorePrep]
+    [-EnsurePod5]
+    [-H1Nester]
 
     [-SingleEncoding]
 
